 #!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get plex.@main[0].image_name 2>/dev/null)
}

do_install_detail() {
  local hostnet=$(uci get plex.@main[0].hostnet 2>/dev/null)
  local claim_token=$(uci get plex.@main[0].claim_token 2>/dev/null)
  local port=$(uci get plex.@main[0].port 2>/dev/null)
  local IMAGE_NAME=$(uci get plex.@main[0].image_name 2>/dev/null)
  local config=$(uci get plex.@main[0].config_path 2>/dev/null)
  local media=$(uci get plex.@main[0].media_path 2>/dev/null)
  local cache=$(uci get plex.@main[0].cache_path 2>/dev/null)
  local LAN_IP=$(uci get network.lan.ipaddr)
  LAN_IP="${LAN_IP%/*}"

  if [ -z "$config" ] || [ -z "$media" ]; then
    echo "config or media path is empty!"
    exit 1
  fi

  [ -z "$port" ] && port=32400
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME="lscr.io/linuxserver/plex:latest"

  rm -R /opt/docker2/compose/plex-app
  mkdir /opt/docker2/compose/plex-app

  touch /opt/docker2/compose/plex-app/docker-compose.yml
  cat > /opt/docker2/compose/plex-app/docker-compose.yml <<EOF
version: "2.1"
services:
  plex:
    image: $IMAGE_NAME
    container_name: plex
    network_mode: host
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=Etc/UTC
      - VERSION=docker
      - PLEX_CLAIM=${claim_token}
    volumes:
      - ./config:/config
      - ${config}/tv:/tv
      - ${config}/movies:/movies
    restart: unless-stopped
    labels:
      plugsy.name: "Plex"
      plugsy.category: "Home"
      plugsy.link: "http://${LAN_IP}:${port}"
EOF

  docker-compose -f /opt/docker2/compose/plex-app/docker-compose.yml up -d

  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install Plex"
  echo "      upgrade                Upgrade Plex"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart Plex"
  echo "      status                 Plex status"
  echo "      port                   Plex port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    echo "Stopping and removing containers..."
    for ID in $CONTAINER_IDS; do
      docker stop $ID
      docker rm $ID
    done
    docker rmi -f $IMAGE_NAME
  ;;
  "start"|"stop"|"restart")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker ${ACTION} ${ID}
    done
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
